YoutubeChannel class

YouTube channel metadata with subscriber count, verified status, and available tabs.

Annotations
  • @freezed

Constructors

YoutubeChannel({String? id, String? name, String? url, @Default.new([]) List<String> avatars, @Default.new([]) List<String> banners, String? description, String? feedUrl, int? subscriberCount, @Default.new(false) bool isVerified, @Default.new([]) List<ChannelTab> tabs})
const
factory
YoutubeChannel.fromJson(Map<String, dynamic> json)
factory

Properties

avatars List<String>
no setterinherited
banners List<String>
no setterinherited
copyWith → $YoutubeChannelCopyWith<YoutubeChannel>
Create a copy of YoutubeChannel with the given fields replaced by the non-null parameter values.
no setterinherited
description String?
no setterinherited
feedUrl String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
isVerified bool
no setterinherited
name String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriberCount int?
no setterinherited
tabs List<ChannelTab>
no setterinherited
url String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this YoutubeChannel to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited